@@ -164,7 +164,7 @@ def _getIntegerSubscriptLookupCode(
     to_name, subscribed_name, subscript_name, subscript_value, emit, context
 ):
     emit(
-        "%s = LOOKUP_SUBSCRIPT_CONST( %s, %s, %s );"
+        "%s = LOOKUP_SUBSCRIPT_CONST(%s, %s, %s);"
         % (to_name, subscribed_name, subscript_name, subscript_value)
     )
 
@@ -179,9 +179,7 @@ def _getIntegerSubscriptLookupCode(
 
 
 def _getSubscriptLookupCode(to_name, subscript_name, subscribed_name, emit, context):
-    emit(
-        "%s = LOOKUP_SUBSCRIPT( %s, %s );" % (to_name, subscribed_name, subscript_name)
-    )
+    emit("%s = LOOKUP_SUBSCRIPT(%s, %s);" % (to_name, subscribed_name, subscript_name))
 
     getErrorExitCode(
         check_name=to_name,
@@ -201,7 +199,7 @@ def _getIntegerSubscriptAssignmentCode(
     res_name = context.allocateTempName("ass_subscript_res", "int")
 
     emit(
-        "%s = SET_SUBSCRIPT_CONST( %s, %s, %s, %s );"
+        "%s = SET_SUBSCRIPT_CONST(%s, %s, %s, %s);"
         % (res_name, subscribed_name, subscript_name, subscript_value, value_name)
     )
 
@@ -217,7 +215,7 @@ def _getSubscriptAssignmentCode(target_name, subscript_name, value_name, emit, c
     res_name = context.getBoolResName()
 
     emit(
-        "%s = SET_SUBSCRIPT( %s, %s, %s );"
+        "%s = SET_SUBSCRIPT(%s, %s, %s);"
         % (res_name, target_name, subscript_name, value_name)
     )
 
@@ -232,7 +230,7 @@ def _getSubscriptAssignmentCode(target_name, subscript_name, value_name, emit, c
 def _getSubscriptDelCode(target_name, subscript_name, emit, context):
     res_name = context.getBoolResName()
 
-    emit("%s = DEL_SUBSCRIPT( %s, %s );" % (res_name, target_name, subscript_name))
+    emit("%s = DEL_SUBSCRIPT(%s, %s);" % (res_name, target_name, subscript_name))
 
     getErrorExitBoolCode(
         condition="%s == false" % res_name,
