@@ -142,7 +142,7 @@ of '--include-plugin-directory' or '--include-plugin-files'."""
                     if assign_source.getLeft().getVariable() is target_var:
                         if assign_source.isInplaceSuspect():
                             node.markAsInplaceSuspect()
-                elif left_arg.isExpressionLocalsVariableRefORFallback():
+                elif left_arg.isExpressionLocalsVariableRefOrFallback():
                     assign_source.unmarkAsInplaceSuspect()
 
         if node.isStatementLocalsDictOperationSet():
