@@ -18,15 +18,14 @@
 """ Details see below in class definition.
 """
 import os
-import pkgutil
 import re
 import shutil
 import sys
-from logging import info, warning
+from logging import info
 
 from nuitka import Options
 from nuitka.plugins.PluginBase import NuitkaPluginBase
-from nuitka.utils.FileOperations import copyTree, makePath
+from nuitka.utils.FileOperations import makePath
 from nuitka.utils.Utils import isWin32Windows
 
 # ------------------------------------------------------------------------------
@@ -36,26 +35,6 @@ from nuitka.utils.Utils import isWin32Windows
 # ------------------------------------------------------------------------------
 
 
-def remove_suffix(string, suffix):
-    """ Remove the given suffix from a string.
-
-    Notes:
-        If the string does indeed end with it. Otherwise, it return the string unmodified.
-
-    Args:
-        string: the string from which to cut off a suffix
-        suffix: this should be cut off the string
-    Returns:
-        string from which the suffix was removed
-    """
-    # Special case: if suffix is empty, string[:0] returns ''. So, test
-    # for a non-empty suffix.
-    if suffix and string.endswith(suffix):
-        return string[: -len(suffix)]
-    else:
-        return string
-
-
 def get_sys_prefix():
     """ Return sys.prefix as guaranteed abspath format.
     """
@@ -64,56 +43,12 @@ def get_sys_prefix():
     return sys_prefix
 
 
-def get_module_file_attribute(package):
-    """ Get the absolute path of the module with the passed-in name.
-
-    Args:
-        package: the fully-qualified name of this module.
-    Returns:
-        absolute path of this module.
-    """
-    loader = pkgutil.find_loader(package)
-    attr = loader.get_filename(package)
-    if not attr:
-        raise ImportError
-    return attr
-
-
-def get_package_paths(package):
-    """ Return the path to package stored on this machine.
-
-    Notes:
-        Also returns the path to this particular package. For example, if
-        pkg.subpkg lives in /abs/path/to/python/libs, then this function returns
-        (/abs/path/to/python/libs, /abs/path/to/python/libs/pkg/subpkg).
-    Args:
-        package: package name
-    Returns:
-        tuple
-    """
-
-    file_attr = get_module_file_attribute(package)
-
-    # package.__file__ = /abs/path/to/package/subpackage/__init__.py.
-    # Search for Python files in /abs/path/to/package/subpackage.
-    # pkg_dir stores this path.
-    pkg_dir = os.path.dirname(file_attr)
-
-    # When found, remove /abs/path/to/ from the filename.
-    # pkg_base stores this path to be removed.
-    pkg_base = remove_suffix(pkg_dir, package.replace(".", os.sep))
-
-    return pkg_base, pkg_dir
-
-
-def get_scipy_core_binaries():
+def get_scipy_core_binaries(module):
     """ Return binaries from the extra-dlls folder (Windows only).
     """
     binaries = []
-
-    extra_dll = os.path.join(
-        os.path.dirname(get_module_file_attribute("scipy")), "extra-dll"
-    )
+    scipy_dir = module.getCompileTimeDirectory()
+    extra_dll = os.path.join(scipy_dir, "extra-dll")
     if not os.path.isdir(extra_dll):
         return binaries
 
@@ -128,19 +63,7 @@ def get_scipy_core_binaries():
     return binaries
 
 
-def get_matplotlib_data():
-    """ Return 'mpl-data' folder name for matplotlib.
-    """
-    mpl_data = os.path.join(
-        os.path.dirname(get_module_file_attribute("matplotlib")), "mpl-data"
-    )
-    if not os.path.isdir(mpl_data):
-        return None
-    suffix_start = mpl_data.find("matplotlib")
-    return mpl_data, suffix_start
-
-
-def get_numpy_core_binaries():
+def get_numpy_core_binaries(module):
     """ Return any binaries in numpy/core and/or numpy/.libs, whether or not actually used by our script.
 
     Notes:
@@ -149,25 +72,26 @@ def get_numpy_core_binaries():
     Returns:
         tuple of abspaths of binaries
     """
-
+    numpy_dir = module.getCompileTimeDirectory()
+    numpy_core_dir = os.path.join(numpy_dir, "core")
     base_prefix = get_sys_prefix()
-    suffix_start = len(base_prefix) + 1
+
     binaries = []
 
     # first look in numpy/.libs for binaries
-    _, pkg_dir = get_package_paths("numpy")
-    libdir = os.path.join(pkg_dir, ".libs")
+    libdir = os.path.join(numpy_dir, ".libs")
     suffix_start = len(libdir) + 1
     if os.path.isdir(libdir):
-        dlls_pkg = [f for f in os.listdir(libdir)]
+        dlls_pkg = os.listdir(libdir)
         binaries += [[os.path.join(libdir, f), suffix_start] for f in dlls_pkg]
 
     # then look for libraries in numpy.core package path
     # should already return the MKL files in ordinary cases
-    _, pkg_dir = get_package_paths("numpy.core")
+
     re_anylib = re.compile(r"\w+\.(?:dll|so|dylib)", re.IGNORECASE)
-    dlls_pkg = [f for f in os.listdir(pkg_dir) if re_anylib.match(f)]
-    binaries += [[os.path.join(pkg_dir, f), suffix_start] for f in dlls_pkg]
+
+    dlls_pkg = [f for f in os.listdir(numpy_core_dir) if re_anylib.match(f)]
+    binaries += [[os.path.join(numpy_core_dir, f), suffix_start] for f in dlls_pkg]
 
     # Also look for MKL libraries in folder "above" numpy.
     # This should meet the layout of Anaconda installs.
@@ -222,9 +146,12 @@ class NumpyPlugin(NuitkaPluginBase):
     def __init__(self):
         self.enabled_plugins = None  # list of active standard plugins
         self.numpy_copied = False  # indicator: numpy files copied
-        self.scipy_copied = False  # indicator: scipy files copied
-        self.mpl_copied = False  # indicator: mpl-data files copied
-        self.sklearn_copied = False  # indicator: sklearn files copied
+        self.matplotlib = self.getPluginOptionBool("matplotlib", False)
+        self.scipy = self.getPluginOptionBool("scipy", False)
+        if self.scipy:
+            self.scipy_copied = False  # indicator: scipy files copied
+        else:
+            self.scipy_copied = True
 
     def considerExtraDlls(self, dist_dir, module):
         """ Copy extra shared libraries or data for this installation.
@@ -235,46 +162,32 @@ class NumpyPlugin(NuitkaPluginBase):
         Returns:
             empty tuple
         """
-        # pylint: disable=too-many-branches,too-many-locals,too-many-return-statements,too-many-statements
         full_name = module.getFullName()
-        if full_name not in ("numpy", "scipy", "matplotlib", "sklearn.datasets"):
-            return ()
 
-        if full_name == "numpy":
-            if self.numpy_copied:
-                return ()
+        if full_name == "numpy" and not self.numpy_copied:
             self.numpy_copied = True
-            binaries = get_numpy_core_binaries()
+            binaries = get_numpy_core_binaries(module)
+
+            for f in binaries:
+                bin_file, idx = f  # (filename, pos. prefix + 1)
+                back_end = bin_file[idx:]
+                tar_file = os.path.join(dist_dir, back_end)
+                makePath(  # create any missing intermediate folders
+                    os.path.dirname(tar_file)
+                )
+                shutil.copyfile(bin_file, tar_file)
+
             bin_total = len(binaries)  # anything there at all?
-            if bin_total == 0:
-                return ()
-
-            for f in binaries:
-                bin_file, idx = f  # (filename, pos. prefix + 1)
-                back_end = bin_file[idx:]
-                tar_file = os.path.join(dist_dir, back_end)
-                makePath(  # create any missing intermediate folders
-                    os.path.dirname(tar_file)
+            if bin_total > 0:
+                msg = "Copied %i %s from 'numpy' installation." % (
+                    bin_total,
+                    "file" if bin_total < 2 else "files",
                 )
-                shutil.copyfile(bin_file, tar_file)
+                info(msg)
 
-            msg = "Copied %i %s from 'numpy' installation." % (
-                bin_total,
-                "file" if bin_total < 2 else "files",
-            )
-            info(msg)
-            return ()
-
-        if full_name == "scipy":
-            if self.scipy_copied:
-                return ()
+        if full_name == "scipy" and not self.scipy_copied:
             self.scipy_copied = True
-            if not self.getPluginOptionBool("scipy", False):
-                return ()
-            binaries = get_scipy_core_binaries()
-            bin_total = len(binaries)
-            if bin_total == 0:
-                return ()
+            binaries = get_scipy_core_binaries(module)
 
             for f in binaries:
                 bin_file, idx = f  # (filename, pos. prefix + 1)
@@ -285,92 +198,60 @@ class NumpyPlugin(NuitkaPluginBase):
                 )
                 shutil.copyfile(bin_file, tar_file)
 
-            msg = "Copied %i %s from 'scipy' installation." % (
-                bin_total,
-                "file" if bin_total < 2 else "files",
-            )
-            info(msg)
-            return ()
+            bin_total = len(binaries)
+            if bin_total > 0:
+                msg = "Copied %i %s from 'scipy' installation." % (
+                    bin_total,
+                    "file" if bin_total < 2 else "files",
+                )
+                info(msg)
 
-        if full_name == "matplotlib":
-            if self.mpl_copied:
-                return ()
-            self.mpl_copied = True
-            if not self.getPluginOptionBool("matplotlib", False):
-                return ()
-            mpl_data = get_matplotlib_data()
-            if not mpl_data:
-                warning("'mpl-data' folder not found in matplotlib.")
-                return ()
-            mpl_data, idx = mpl_data  # (folder, pos. of 'matplotlib')
-            back_end = mpl_data[idx:]
-            tar_dir = os.path.join(dist_dir, back_end)
-            copyTree(mpl_data, tar_dir)
+        return ()
 
-            msg = "Copied 'mpl-data' from 'matplotlib' installation."
-            info(msg)
-            return ()
-
-        if full_name == "sklearn.datasets":
-            if self.sklearn_copied:
-                return ()
-            self.sklearn_copied = True
-            if not self.getPluginOptionBool("sklearn", False):
-                return ()
-            sklearn_dir = os.path.dirname(get_module_file_attribute("sklearn"))
-            source_data = os.path.join(sklearn_dir, "datasets", "data")
-            target_data = os.path.join(dist_dir, "sklearn", "datasets", "data")
-            source_descr = os.path.join(sklearn_dir, "datasets", "descr")
-            target_descr = os.path.join(dist_dir, "sklearn", "datasets", "descr")
-            copyTree(source_data, target_data)
-            info("Copied folder sklearn/datasets/data")
-            copyTree(source_descr, target_descr)
-            info("Copied folder sklearn/datasets/descr")
-            return ()
-
-    def onModuleEncounter(
-        self, module_filename, module_name, module_package, module_kind
-    ):
+    def onModuleEncounter(self, module_filename, module_name, module_kind):
         # pylint: disable=too-many-branches,too-many-return-statements
-        if module_package == "scipy.sparse.csgraph" and module_name == "_validation":
+        elements = module_name.split(".")
+        if not self.scipy and elements[0] in ("scipy", "sklearn"):
+            return False, "Omit unneeded components"
+
+        if module_name == "scipy.sparse.csgraph._validation":
             return True, "Replicate implicit import"
 
-        if module_package is None:
+        if elements[0] == "mpl_toolkits" and self.matplotlib is True:
+            return True, "Needed by matplotlib"
+
+        if module_name.getPackageName() is None:
             return None
-        if module_package == module_name:
-            full_name = module_package
-        else:
-            full_name = module_package + "." + module_name
 
-        if full_name in ("cv2", "cv2.cv2", "cv2.data"):
-            return True, "needed for OpenCV"
+        if module_name in ("cv2", "cv2.cv2", "cv2.data"):
+            return True, "Needed for OpenCV"
 
-        if module_package == "sklearn.utils.sparsetools" and module_name in (
-            "_graph_validation",
-            "_graph_tools",
+        if module_name in (
+            "sklearn.utils.sparsetools._graph_validation",
+            "sklearn.utils.sparsetools._graph_tools",
         ):
             return True, "Needed by sklearn"
 
-        if module_package == "sklearn.utils" and module_name in (
-            "lgamma",
-            "weight_vector",
-            "_unittest_backport",
+        if module_name in (
+            "sklearn.utils.lgamma",
+            "sklearn.utils.weight_vector",
+            "sklearn.utils._unittest_backport",
         ):
             return True, "Needed by sklearn"
 
         posix = (
-            "managers",
-            "synchronize",
-            "compat_posix",
-            "_posix_reduction",
-            "popen_loky_posix",
+            "sklearn.externals.joblib.externals.loky.backend.managers",
+            "sklearn.externals.joblib.externals.loky.backend.synchronize",
+            "sklearn.externals.joblib.externals.loky.backend.compat_posix",
+            "sklearn.externals.joblib.externals.loky.backend._posix_reduction",
+            "sklearn.externals.joblib.externals.loky.backend.popen_loky_posix",
         )
         win32 = (
-            "managers",
-            "synchronize",
-            "_win_wait",
-            "_win_reduction",
-            "popen_loky_win32",
+            "sklearn.externals.joblib.externals.loky.backend.managers",
+            "sklearn.externals.joblib.externals.loky.backend.synchronize",
+            "sklearn.externals.joblib.externals.loky.backend._win_wait",
+            "sklearn.externals.joblib.externals.loky.backend._win_reduction",
+            "sklearn.externals.joblib.externals.loky.backend.popen_loky_win32",
         )
 
         if isWin32Windows():
@@ -378,32 +259,31 @@ class NumpyPlugin(NuitkaPluginBase):
         else:
             valid_list = posix
 
-        if (
-            module_package == "sklearn.externals.joblib.externals.loky.backend"
-            and module_name in valid_list
-        ):
+        if module_name in valid_list:
             return True, "Needed by sklearn"
 
-        if (
-            module_package == "sklearn.externals.joblib.externals.cloudpickle"
-            and module_name == "dumps"
-        ):
+        if module_name == "sklearn.externals.joblib.externals.cloudpickle.dumps":
             return True, "Needed by sklearn"
 
         # some special handling for matplotlib:
         # keep certain modules depending on whether Tk or Qt plugins are enabled
         if self.enabled_plugins is None:
-            self.enabled_plugins = [p for p in Options.getPluginsEnabled()]
+            self.enabled_plugins = Options.getPluginsEnabled()
 
-        if module_package == "matplotlib.backends":
-            if "tk-inter" in self.enabled_plugins and (
-                "backend_tk" in module_name or "tkagg" in module_name
+        if "tk-inter" in self.enabled_plugins:
+            if module_name in (
+                "matplotlib.backends.backend_tk",
+                "matplotlib.backends.backend_tkagg",
+                "matplotlib.backend.tkagg",
             ):
-                return True, "needed for tkinter interaction"
-            if "qt-plugins" in self.enabled_plugins and "backend_qt" in module_name:
-                return True, "needed for Qt interaction"
-            if module_name == "backend_agg":
-                return True, "needed as standard backend"
+                return True, "Needed for tkinter interaction"
+
+        if "qt-plugins" in self.enabled_plugins:
+            if module_name == "matplotlib.backends.backend_qt":
+                return True, "Needed for Qt interaction"
+
+        if module_name == "matplotlib.backends.backend_agg":
+            return True, "Needed as standard backend"
 
 
 class NumpyPluginDetector(NuitkaPluginBase):
