@@ -32,6 +32,7 @@ import sys
 import tempfile
 import time
 
+from nuitka.PythonVersions import python_version
 from nuitka.tools.testing.Common import (
     addToPythonPath,
     getTestingCPythonOutputsCacheDir,
@@ -39,6 +40,7 @@ from nuitka.tools.testing.Common import (
 )
 from nuitka.tools.testing.OutputComparison import compareOutput
 from nuitka.Tracing import my_print
+from nuitka.utils.Execution import check_output
 from nuitka.utils.Timing import StopWatch
 
 
@@ -124,6 +126,19 @@ def getCPythonResults(cpython_cmd, cpython_cached):
                 with open(element, "rb") as element_file:
                     command_hash.update(element_file.read())
 
+        hash_salt = os.environ.get("NUITKA_HASH_SALT", "")
+
+        if str is not bytes:
+            hash_salt = hash_salt.encode("utf8")
+        command_hash.update(hash_salt)
+
+        if os.name == "nt" and python_version < 300:
+            curdir = os.getcwdu()
+        else:
+            curdir = os.getcwd()
+
+        command_hash.update(curdir.encode("utf8"))
+
         cache_filename = os.path.join(
             getTestingCPythonOutputsCacheDir(), command_hash.hexdigest()
         )
@@ -152,7 +167,6 @@ def getCPythonResults(cpython_cmd, cpython_cached):
 
 def main():
     # Of course many cases to deal with, pylint: disable=too-many-branches,too-many-locals,too-many-statements
-    from nuitka.utils.Execution import check_output
 
     filename = sys.argv[1]
     args = sys.argv[2:]
@@ -528,49 +542,58 @@ Taking coverage of '{filename}' using '{python}' with flags {args} ...""".format
         if trace_command:
             my_print("Nuitka command 1:", nuitka_cmd1)
 
-        with withPythonPathChange(nuitka_package_dir):
-            process = subprocess.Popen(
-                args=nuitka_cmd1, stdout=subprocess.PIPE, stderr=subprocess.PIPE
-            )
+        for _i in range(5):
+            with withPythonPathChange(nuitka_package_dir):
+                process = subprocess.Popen(
+                    args=nuitka_cmd1, stdout=subprocess.PIPE, stderr=subprocess.PIPE
+                )
 
-        stdout_nuitka1, stderr_nuitka1 = process.communicate()
-        exit_nuitka1 = process.returncode
+            stdout_nuitka1, stderr_nuitka1 = process.communicate()
+            exit_nuitka1 = process.returncode
 
-        if exit_nuitka1 != 0:
-            if (
-                not expect_failure
-                and not comparison_mode
-                and not os.path.exists(".coverage")
-            ):
-                sys.exit(
-                    """\
+            if exit_nuitka1 != 0:
+                if (
+                    not expect_failure
+                    and not comparison_mode
+                    and not os.path.exists(".coverage")
+                ):
+                    sys.exit(
+                        """\
 Error, failed to take coverage with '%s'.
 
 Stderr was:
 %s
 """
-                    % (os.environ["PYTHON"], stderr_nuitka1)
-                )
+                        % (os.environ["PYTHON"], stderr_nuitka1)
+                    )
 
-            exit_nuitka = exit_nuitka1
-            stdout_nuitka, stderr_nuitka = stdout_nuitka1, stderr_nuitka1
-        else:
-            # No execution second step for coverage mode.
-            if comparison_mode:
-                if trace_command:
-                    my_print("Nuitka command 2:", nuitka_cmd2)
-
-                process = subprocess.Popen(
-                    args=nuitka_cmd2, stdout=subprocess.PIPE, stderr=subprocess.PIPE
-                )
-
-                stdout_nuitka2, stderr_nuitka2 = process.communicate()
-                stdout_nuitka = stdout_nuitka1 + stdout_nuitka2
-                stderr_nuitka = stderr_nuitka1 + stderr_nuitka2
-                exit_nuitka = process.returncode
-            else:
                 exit_nuitka = exit_nuitka1
                 stdout_nuitka, stderr_nuitka = stdout_nuitka1, stderr_nuitka1
+            else:
+                # No execution second step for coverage mode.
+                if comparison_mode:
+                    if trace_command:
+                        my_print("Nuitka command 2:", nuitka_cmd2)
+
+                    process = subprocess.Popen(
+                        args=nuitka_cmd2, stdout=subprocess.PIPE, stderr=subprocess.PIPE
+                    )
+
+                    stdout_nuitka2, stderr_nuitka2 = process.communicate()
+                    stdout_nuitka = stdout_nuitka1 + stdout_nuitka2
+                    stderr_nuitka = stderr_nuitka1 + stderr_nuitka2
+                    exit_nuitka = process.returncode
+                else:
+                    exit_nuitka = exit_nuitka1
+                    stdout_nuitka, stderr_nuitka = stdout_nuitka1, stderr_nuitka1
+
+            if checkNoPermissionError(stdout_nuitka) and checkNoPermissionError(
+                stderr_nuitka
+            ):
+                break
+
+            my_print("Retrying nuitka exe due to permission problems after delay.")
+            time.sleep(2)
 
     stop_watch.stop()
     nuitka_time = stop_watch.delta()
@@ -618,7 +641,7 @@ Exit codes {exit_cpython:d} (CPython) != {exit_nuitka:d} (Nuitka)""".format(
         # without stdin forwarded.
         if (
             exit_code_return
-            and exit_nuitka == -11
+            and exit_nuitka in (-11, -6)
             and sys.platform != "nt"
             and not module_mode
             and not two_step_execution
