@@ -99,7 +99,7 @@ constructs fully away. Default is %default.""",
         "--skip-standalone-tests",
         action="store_false",
         dest="standalone_tests",
-        default=os.name != "posix" or os.uname()[0] != "NetBSD",  # @UndefinedVariable
+        default=os.name != "posix" or os.uname()[0] != "NetBSD",
         help="""\
 The standalone tests, execute these to check if Nuitka standalone mode, e.g.
 not referring to outside, important 3rd library packages like PyQt fine.
@@ -290,6 +290,15 @@ Do not use Python3.6 even if available on the system. Default is %default.""",
 Do not use Python3.7 even if available on the system. Default is %default.""",
     )
 
+    parser.add_option(
+        "--no-python3.8",
+        action="store_true",
+        dest="no38",
+        default=False,
+        help="""\
+Do not use Python3.8 even if available on the system. Default is %default.""",
+    )
+
     parser.add_option(
         "--coverage",
         action="store_true",
@@ -321,6 +330,8 @@ Make a coverage analysis, that does not really check. Default is %default.""",
             options.no36 = True
         if sys.version_info[0:2] != (3, 7):
             options.no37 = True
+        if sys.version_info[0:2] != (3, 8):
+            options.no38 = True
 
     if options.cpython_no_other:
         if sys.version_info[0:2] != (2, 6):
@@ -452,6 +463,8 @@ def main():
             return False
         if command == "python3.7" and options.no37:
             return False
+        if command == "python3.8" and options.no38:
+            return False
 
         # Shortcuts for python versions, also needed for Windows as it won't have
         # the version number in the Python binaries at all.
@@ -469,6 +482,8 @@ def main():
             return True
         if command == "python3.7" and sys.version_info[0:2] == (3, 7):
             return True
+        if command == "python3.8" and sys.version_info[0:2] == (3, 8):
+            return True
 
         path = os.environ["PATH"]
 
@@ -707,6 +722,7 @@ def main():
         or checkExecutableCommand("python3.5")
         or checkExecutableCommand("python3.6")
         or checkExecutableCommand("python3.7")
+        or checkExecutableCommand("python3.8")
     )
 
     if checkExecutableCommand("python2.6"):
@@ -754,6 +770,11 @@ def main():
     else:
         print("Cannot execute tests with Python 3.7, disabled or not installed.")
 
+    if checkExecutableCommand("python3.8"):
+        execute_tests("python3.8-nodebug", "python3.8", "")
+    else:
+        print("Cannot execute tests with Python 3.8, disabled or not installed.")
+
     if options.coverage:
         publishCoverageData()
 
